#
# Copyright (c) 2008-2019 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from zope.interface import Interface

from pyams_content.shared.imagemap.portlet import IImageMapPortletSettings
from pyams_form.form import AJAXEditForm
from pyams_pagelet.interfaces import IPagelet
from pyams_pagelet.pagelet import pagelet_config
from pyams_portal.interfaces import IPortletPreviewer
from pyams_portal.portlet import PortletPreviewer
from pyams_portal.zmi.portlet import PortletSettingsEditor
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION


__docformat__ = 'restructuredtext'


@pagelet_config(name='properties.html', context=IImageMapPortletSettings, layer=IPyAMSLayer,
                permission=VIEW_SYSTEM_PERMISSION)
class ImageMapPortletSettingsEditor(PortletSettingsEditor):
    """Image map portlet settings editor"""

    settings = IImageMapPortletSettings


@adapter_config(name='properties.json', context=(IImageMapPortletSettings, IPyAMSLayer),
                provides=IPagelet)
class ImageMapPortletSettingsAJAXEditor(AJAXEditForm, ImageMapPortletSettingsEditor):
    """Image mpa portlet settings editor, JSON renderer"""


@adapter_config(context=(Interface, IPyAMSLayer, Interface, IImageMapPortletSettings),
                provides=IPortletPreviewer)
@template_config(template='templates/imagemap-preview.pt', layer=IPyAMSLayer)
class ImageMapPortletPreviewer(PortletPreviewer):
    """Image map portlet previewer"""
